aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/extension/manager.php
diff options
context:
space:
mode:
authorn-aleha <nick_aleha@myway.com>2014-05-12 01:00:59 +0300
committern-aleha <nick_aleha@myway.com>2014-05-29 01:07:44 +0300
commit031273de728e2c69e583cc4beef49087228cbc2c (patch)
tree636bd74248fc0f3ac45231c8adfa8f02dad6f3cd /phpBB/phpbb/extension/manager.php
parent305be2ae64dc3236d9e39a97d35394ba171482b1 (diff)
downloadforums-031273de728e2c69e583cc4beef49087228cbc2c.tar
forums-031273de728e2c69e583cc4beef49087228cbc2c.tar.gz
forums-031273de728e2c69e583cc4beef49087228cbc2c.tar.bz2
forums-031273de728e2c69e583cc4beef49087228cbc2c.tar.xz
forums-031273de728e2c69e583cc4beef49087228cbc2c.zip
[ticket/11467] Add language variables for extension exception messages
Remove hard-coded messages and add language variables for extension exception messages. PHPBB3-11467
Diffstat (limited to 'phpBB/phpbb/extension/manager.php')
-rw-r--r--phpBB/phpbb/extension/manager.php17
1 files changed, 10 insertions, 7 deletions
diff --git a/phpBB/phpbb/extension/manager.php b/phpBB/phpbb/extension/manager.php
index 0bfec23573..50877c9ca1 100644
--- a/phpBB/phpbb/extension/manager.php
+++ b/phpBB/phpbb/extension/manager.php
@@ -26,6 +26,7 @@ class manager
protected $db;
protected $config;
protected $cache;
+ protected $user;
protected $php_ext;
protected $extensions;
protected $extension_table;
@@ -37,24 +38,26 @@ class manager
*
* @param ContainerInterface $container A container
* @param \phpbb\db\driver\driver_interface $db A database connection
- * @param \phpbb\config\config $config \phpbb\config\config
+ * @param \phpbb\config\config $config Config object
* @param \phpbb\filesystem $filesystem
* @param string $extension_table The name of the table holding extensions
* @param string $phpbb_root_path Path to the phpbb includes directory.
* @param string $php_ext php file extension
* @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
* @param string $cache_name The name of the cache variable, defaults to _ext
*/
- public function __construct(ContainerInterface $container, \phpbb\db\driver\driver_interface $db, \phpbb\config\config $config, \phpbb\filesystem $filesystem, $extension_table, $phpbb_root_path, $php_ext = 'php', \phpbb\cache\driver\driver_interface $cache = null, $cache_name = '_ext')
+ public function __construct(ContainerInterface $container, \phpbb\db\driver\driver_interface $db, \phpbb\config\config $config, \phpbb\filesystem $filesystem, $extension_table, $phpbb_root_path, $php_ext = 'php', \phpbb\user $user, \phpbb\cache\driver\driver_interface $cache = null, $cache_name = '_ext')
{
$this->container = $container;
- $this->phpbb_root_path = $phpbb_root_path;
$this->db = $db;
$this->config = $config;
- $this->cache = $cache;
$this->filesystem = $filesystem;
- $this->php_ext = $php_ext;
$this->extension_table = $extension_table;
+ $this->phpbb_root_path = $phpbb_root_path;
+ $this->php_ext = $php_ext;
+ $this->user = $user;
+ $this->cache = $cache;
$this->cache_name = $cache_name;
$this->extensions = ($this->cache) ? $this->cache->get($this->cache_name) : false;
@@ -150,7 +153,7 @@ class manager
*/
public function create_extension_metadata_manager($name, \phpbb\template\template $template)
{
- return new \phpbb\extension\metadata_manager($name, $this->config, $this, $template, $this->phpbb_root_path);
+ return new \phpbb\extension\metadata_manager($name, $this->config, $this, $template, $this->user, $this->phpbb_root_path);
}
/**
@@ -37,24 +38,26 @@ class manager
* @param string $extension_table The name of the table holding extensions
* @param string $phpbb_root_path Path to the phpbb includes directory.
- * @param string $php_ext php file extension
+ * @param string $php_ext php file extension, defaults to php
+ * @param \phpbb\user $user User object
* @param \phpbb\cache\driver\driver_interface $cache A cache instance or null
* @param string $cache_name The name of the cache variable, defaults to _ext